@@ -109,6 +109,14 @@
 #' genotyping model, a proposed model, a truncated model, and a
 #' frequency-based model.}
 #'
+#' @note
+#'
+#' When IMresult and MIMresult are entered simultaneously, only IMresult will
+#' be processed.
+#'
+#' If an error occurs, please check whether the original output data of
+#' IM.search(), MIM.result(), or MIM.points() is used.
+#'
 #' @export
 #'
 #' @references
@@ -160,7 +168,7 @@
 EM.MIM <- function(QTL = NULL, marker = NULL, geno = NULL, D.matrix = NULL, cp.matrix = NULL, y = NULL,
                    yu = NULL, sele.g = "n", tL = NULL, tR = NULL, type = "RI", ng = 2, cM = TRUE,
                    E.vector0 = NULL, X = NULL, beta0 = NULL, variance0 = NULL, crit = 10^-5,
-                   stop = 1000, conv = TRUE, console = TRUE, IMresult = NULL, MIMresult = NULL){
+                   stop = 1000, conv = TRUE, console = interactive(), IMresult = NULL, MIMresult = NULL){
 
   if(!is.null(IMresult)){
     check1 <- names(IMresult) == c("effect", "LRT.threshold", "detect.QTL", "model", "inputdata")
@@ -190,8 +198,6 @@ EM.MIM <- function(QTL = NULL, marker = NULL, geno = NULL, D.matrix = NULL, cp.m
             }
           }
         }
-        cat("Use the output data of IM.search() for analysis. \n")
-        cat("If an error occurs, please check whether the original output data of IM.search() is used. \n")
       }
     }
   } else if(!is.null(MIMresult)){
@@ -217,8 +223,6 @@ EM.MIM <- function(QTL = NULL, marker = NULL, geno = NULL, D.matrix = NULL, cp.m
         if(is.null(D.matrix)){
           D.matrix <- MIMresult$inputdata$D.matrix
         }
-        cat("Use the output data of MIM.search()/MIM.points() for analysis. \n")
-        cat("If an error occurs, please check whether the original output data of MIM.search()/MIM.points() is used. \n")
       }
     }
   }
