@@ -4,7 +4,7 @@
 #'
 #' @param LOD.QTLdetect.result list. The data list of the output from
 #' LOD.QTLdetect().
-#' @param ptime integer. The permutation times.
+#' @param npermu integer. The number of permutations.
 #' @param alpha numeric. The type 1 error rate of detecting the hotspot.
 #' @param Q logical. When set to TRUE, the function will additionally carry
 #' out the permutation of the Q method as the control group, which will be
@@ -42,9 +42,9 @@
 #' load(system.file("extdata", "LODexample.RDATA", package = "QTLEMM"))
 #'
 #' # run and result
-#' result <- EQF.permu(LOD.QTLdetect.result, ptime = 50)
+#' result <- EQF.permu(LOD.QTLdetect.result, npermu = 50)
 #' result$cluster.number
-EQF.permu <- function(LOD.QTLdetect.result, ptime = 1000, alpha = 0.05, Q = TRUE, console = TRUE){
+EQF.permu <- function(LOD.QTLdetect.result, npermu = 1000, alpha = 0.05, Q = TRUE, console = interactive()){
 
   datatest <- names(LOD.QTLdetect.result) != c("detect.QTL.number", "QTL.matrix", "EQF.matrix",
                                                "linkage.QTL.number", "LOD.threshold", "bin")
@@ -52,8 +52,8 @@ EQF.permu <- function(LOD.QTLdetect.result, ptime = 1000, alpha = 0.05, Q = TRUE
     stop("Input data error, please input the original output data of LOD.QTLdetect.", call. = FALSE)
   }
 
-  if(!is.numeric(ptime) | length(ptime) > 1 | min(ptime) < 0){
-    stop("Parameter ptime error, please input a positive integer.", call. = FALSE)
+  if(!is.numeric(npermu) | length(npermu) > 1 | min(npermu) < 0){
+    stop("Parameter npermu error, please input a positive integer.", call. = FALSE)
   }
 
   if(!is.numeric(alpha) | length(alpha) > 1 | min(alpha) < 0 | max(alpha) > 1){
@@ -159,14 +159,14 @@ EQF.permu <- function(LOD.QTLdetect.result, ptime = 1000, alpha = 0.05, Q = TRUE
     } else {clumatrix[i,] <- submatrix}
   }
 
-  eqf.premutation <- function(eqfmatrix, ptime = ptime, console = console){
+  eqf.premutation <- function(eqfmatrix, npermu = npermu, console = console){
     t0 <- Sys.time()
     cat("permutation time \n"[console])
     n <- ncol(eqfmatrix)
     g <- nrow(eqfmatrix)
-    out <- matrix(0, ptime, n)
+    out <- matrix(0, npermu, n)
 
-    for(i in 1:ptime){
+    for(i in 1:npermu){
       p.matrix <- matrix(0, g, n)
       for(j in 1:g){
         eqfpos <- eqfmatrix[j, eqfmatrix[j,] > 0]
@@ -174,20 +174,20 @@ EQF.permu <- function(LOD.QTLdetect.result, ptime = 1000, alpha = 0.05, Q = TRUE
         p.matrix[j, k] <- eqfpos
       }
       out[i,] <- sort(apply(p.matrix, 2, sum), decreasing = TRUE)
-      cat1 <- paste(paste(i, ptime, sep = "/"), "\n", sep = "\t")
+      cat1 <- paste(paste(i, npermu, sep = "/"), "\n", sep = "\t")
       if(Sys.time()-t0 > 5){
         cat(cat1[console])
         t0 <- Sys.time()
       }
     }
-    cat(paste(paste(ptime, ptime, sep = "/"), "\n", sep = "\t")[console])
+    cat(paste(paste(npermu, npermu, sep = "/"), "\n", sep = "\t")[console])
     return(out)
   }
 
   cat("cluster group permutation \n"[console])
-  permu.clu <- eqf.premutation(clumatrix, ptime, console)
+  permu.clu <- eqf.premutation(clumatrix, npermu, console)
 
-  sortEQF <- function(x, a = ceiling(ptime*alpha)){
+  sortEQF <- function(x, a = ceiling(npermu*alpha)){
     return(sort(x, decreasing = TRUE)[a])
   }
 
@@ -204,7 +204,7 @@ EQF.permu <- function(LOD.QTLdetect.result, ptime = 1000, alpha = 0.05, Q = TRUE
   if(Q){
     cat("Q-method permutation \n"[console])
     q0 <- EQF[apply(EQF, 1, sum) > 0,]
-    permu.q <- eqf.premutation(q0, ptime, console)
+    permu.q <- eqf.premutation(q0, npermu, console)
     thre.q <- apply(permu.q, 2, sortEQF)
     b1 <- thre.q[1]
     beta <- max(which(b1<thre.clu))
