@@ -141,7 +141,7 @@
 IM.search <- function(marker, geno, y, yu = NULL, sele.g = "n", tL = NULL, tR = NULL, method = "EM",
                       type = "RI", D.matrix = NULL, ng = 2, cM = TRUE, speed = 1, crit = 10^-5,
                       d.eff = FALSE, LRT.thre = TRUE, simu = 1000, alpha = 0.05, detect = TRUE,
-                      QTLdist = 15, plot.all = TRUE, plot.chr = TRUE, console = TRUE){
+                      QTLdist = 15, plot.all = TRUE, plot.chr = TRUE, console = interactive()){
 
   if(is.null(marker) | is.null(geno) | is.null(y)){
     stop("Input data is missing. The argument marker, geno, and y must be input.", call. = FALSE)
