@@ -86,6 +86,14 @@
 #' y, yu, sele.g, type, ng, cM, and D.matrix. The parameters not provided by
 #' the user will be output with default values.}
 #'
+#' @note
+#'
+#' When IMresult and MIMresult are entered simultaneously, only IMresult will
+#' be processed.
+#'
+#' If an error occurs, please check whether the original output data of
+#' IM.search(), MIM.result(), or MIM.points() is used.
+#'
 #' @export
 #'
 #' @references
@@ -134,7 +142,7 @@
 #'
 MIM.points <- function(QTL = NULL, marker = NULL, geno = NULL, y = NULL, yu = NULL, sele.g = "n", tL = NULL,
                        tR = NULL, method = "EM", type = "RI", D.matrix = NULL, ng = 2, cM = TRUE, scope = 5,
-                       speed = 1, crit = 10^-3, console = TRUE, IMresult = NULL, MIMresult = NULL){
+                       speed = 1, crit = 10^-3, console = interactive(), IMresult = NULL, MIMresult = NULL){
 
   if(!is.null(IMresult)){
     check1 <- names(IMresult) == c("effect", "LRT.threshold", "detect.QTL", "model", "inputdata")
@@ -159,8 +167,6 @@ MIM.points <- function(QTL = NULL, marker = NULL, geno = NULL, y = NULL, yu = NU
         if(is.null(D.matrix)){
           D.matrix <- MIMresult$inputdata$D.matrix
         }
-        cat("Use the output data of IM.search() for analysis. \n")
-        cat("If an error occurs, please check whether the original output data of IM.search() is used. \n")
       }
     }
   } else if(!is.null(MIMresult)){
@@ -186,8 +192,6 @@ MIM.points <- function(QTL = NULL, marker = NULL, geno = NULL, y = NULL, yu = NU
         if(is.null(D.matrix)){
           D.matrix <- MIMresult$inputdata$D.matrix
         }
-        cat("Use the output data of MIM.search()/MIM.points() for analysis. \n")
-        cat("If an error occurs, please check whether the original output data of MIM.search()/MIM.points() is used. \n")
       }
     }
   }
