@@ -87,6 +87,14 @@
 #' y, yu, sele.g, type, ng, cM, and D.matrix. The parameters not provided by
 #' the user will be output with default values.}
 #'
+#' @note
+#'
+#' When IMresult and MIMresult are entered simultaneously, only IMresult will
+#' be processed.
+#'
+#' If an error occurs, please check whether the original output data of
+#' IM.search(), MIM.result(), or MIM.points() is used.
+#'
 #' @export
 #'
 #' @references
@@ -137,7 +145,7 @@
 #'
 MIM.search <- function(QTL = NULL, marker = NULL, geno = NULL, y = NULL, yu = NULL, sele.g = "n", tL = NULL,
                        tR = NULL, method = "EM", type = "RI", D.matrix = NULL, ng = 2, cM = TRUE, speed = 1,
-                       QTLdist = 15, link = TRUE, crit = 10^-3, console = TRUE, IMresult = NULL, MIMresult = NULL){
+                       QTLdist = 15, link = TRUE, crit = 10^-3, console = interactive(), IMresult = NULL, MIMresult = NULL){
 
   if(!is.null(IMresult)){
     check1 <- names(IMresult) == c("effect", "LRT.threshold", "detect.QTL", "model", "inputdata")
@@ -167,8 +175,6 @@ MIM.search <- function(QTL = NULL, marker = NULL, geno = NULL, y = NULL, yu = NU
             }
           }
         }
-        cat("Use the output data of IM.search() for analysis. \n")
-        cat("If an error occurs, please check whether the original output data of IM.search() is used. \n")
       }
     }
   } else if(!is.null(MIMresult)){
@@ -194,8 +200,6 @@ MIM.search <- function(QTL = NULL, marker = NULL, geno = NULL, y = NULL, yu = NU
         if(is.null(D.matrix)){
           D.matrix <- D.make(nrow(QTL)+1, type = type)
         }
-        cat("Use the output data of MIM.search()/MIM.points() for analysis. \n")
-        cat("If an error occurs, please check whether the original output data of MIM.search()/MIM.points() is used. \n")
       }
     }
   }
