@@ -48,7 +48,7 @@
 #'
 #' # run and result
 #' result <- Qhot(QTL.example, crop.example, 5, 20, 100, save.pdf = FALSE)
-Qhot <- function(DataQTL, DataCrop, ScanStep = 1, NH = 100, NP = 1000, save.pdf = TRUE){
+Qhot <- function(DataQTL, DataCrop, ScanStep = 1, NH = 100, NP = 1000, save.pdf = interactive()){
   DataQTL <- data.frame(DataQTL)
   if(ncol(DataQTL) != 5 | TRUE %in% is.na(DataQTL)){
     stop("Input data DataQTL error, please check and fix.", call. = FALSE)
